%define oname	LibRaw

%define major		20
%define lib_raw		%mklibname raw %{major}
%define lib_raw_r	%mklibname raw_r %{major}
%define devname		%mklibname raw -d

Summary:	Library for reading RAW files obtained from digital photo cameras
Name:		libraw
Version:	0.20.2
Release:	%mkrel 5
License:	LGPLv2 or CDDL
Group:		System/Libraries
URL:		https://www.libraw.org/
Source0:	https://www.libraw.org/data/%{oname}-%{version}.tar.gz
Patch0:		libraw-CVE-2021-32142.patch
Patch1:		libraw-CVE-2023-1729.patch
BuildRequires:	libgomp-devel
BuildRequires:	pkgconfig(lcms2)
BuildRequires:	pkgconfig(jasper)

%description
LibRaw is a library for reading RAW files obtained from digital photo
cameras (CRW/CR2, NEF, RAF, DNG, and others).

#-------------------------------------------------------------------------------

%package tools
Summary:	Tools available in %name
Group:		Graphics/Utilities
Obsoletes:	%{name} < %{version}-%{release}

%description tools
This packages provides tools to manipulate raw files.

%files tools
%{_bindir}/4channels
%{_bindir}/dcraw_emu
%{_bindir}/dcraw_half
%{_bindir}/half_mt
%{_bindir}/mem_image
%{_bindir}/multirender_test
%{_bindir}/postprocessing_benchmark
%{_bindir}/raw-identify
%{_bindir}/rawtextdump
%{_bindir}/simple_dcraw
%{_bindir}/unprocessed_raw

#-------------------------------------------------------------------------------

%package -n %{lib_raw}
Summary:	Raw image decoder library (non-thread-safe)
Group:		System/Libraries

%description -n %{lib_raw}
LibRaw is a library for reading RAW files obtained from digital photo
cameras (CRW/CR2, NEF, RAF, DNG, and others).

%files -n %{lib_raw}
%license LICENSE.*
%doc README.md
%{_libdir}/libraw.so.%{major}{,.*}

#-------------------------------------------------------------------------------

%package -n %{lib_raw_r}
Summary:	Raw image decoder library (thread-safe)
Group:		System/Libraries

%description -n %{lib_raw_r}
LibRaw is a library for reading RAW files obtained from digital photo
cameras (CRW/CR2, NEF, RAF, DNG, and others).

%files -n %{lib_raw_r}
%license LICENSE.*
%doc README.md
%{_libdir}/libraw_r.so.%{major}{,.*}

#-------------------------------------------------------------------------------
 
%package -n %{devname}
Summary:	LibRaw development libraries
Group:		Development/C
Requires:	%{lib_raw} = %{version}-%{release}
Requires:	%{lib_raw_r} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{name}-devel < %{version}-%{release}

%description -n %{devname}
LibRaw development files and headers.

%files -n %{devname}
%doc Changelog.* README*
%{_includedir}/libraw/
%{_libdir}/libraw.so
%{_libdir}/libraw_r.so
%{_libdir}/pkgconfig/libraw.pc
%{_libdir}/pkgconfig/libraw_r.pc

#-------------------------------------------------------------------------------

%prep
%setup -qn %{oname}-%{version}
%autopatch -p1

%build
#autoreconf -if
%configure \
	--disable-static \
	--enable-jasper \
	--enable-jpeg \
	--enable-lcms \
	--enable-openmp
%make_build

%install
%make_install

# let files section handle docs
rm -fr %{buildroot}%{_datadir}/doc/*



%changelog
* Tue May 09 2023 daviddavid <daviddavid> 0.20.2-5.mga9
+ Revision: 1956369
- add upstream patch to fix CVE-2023-1729 (mga#31903)

* Mon Feb 27 2023 ns80 <ns80> 0.20.2-4.mga9
+ Revision: 1945618
- add a patch from openSUSE for CVE-2021-32142 (mga#31594)

* Tue Nov 22 2022 daviddavid <daviddavid> 0.20.2-3.mga9
+ Revision: 1910127
- rebuild for new jasper 3.0.6
+ wally <wally>
- fix license

* Tue Mar 29 2022 umeabot <umeabot> 0.20.2-2.mga9
+ Revision: 1831114
- Mageia 9 Mass Rebuild

* Tue Oct 27 2020 luigiwalser <luigiwalser> 0.20.2-1.mga8
+ Revision: 1639923
- 0.20.2
- remove upstreamed CVE-2020-24890 patch

* Wed Sep 30 2020 ns80 <ns80> 0.20.0-2.mga8
+ Revision: 1631244
- add upstream patch for CVE-2020-24890 (mga#27329)

* Wed Sep 09 2020 zezinho <zezinho> 0.20.0-1.mga8
+ Revision: 1623872
- new major version 0.20.0

* Sun Feb 16 2020 umeabot <umeabot> 0.19.5-2.mga8
+ Revision: 1530519
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Aug 31 2019 zezinho <zezinho> 0.19.5-1.mga8
+ Revision: 1435954
- new version 0.19.5

* Fri Jul 12 2019 daviddavid <daviddavid> 0.19.3-1.mga8
+ Revision: 1420546
- new version: 0.19.3

* Fri Dec 28 2018 zezinho <zezinho> 0.19.2-1.mga7
+ Revision: 1345514
- new version 0.19.2

* Mon Nov 26 2018 zezinho <zezinho> 0.19.1-1.mga7
+ Revision: 1335219
- version 0.19.1

* Sat Aug 25 2018 zezinho <zezinho> 0.19.0-1.mga7
+ Revision: 1254424
- new version 0.19.0 - ABI has changed - 84 cameras added compared to 0.18 - no more built-in support for LibRaw demosaic packs

* Wed Aug 22 2018 zezinho <zezinho> 0.18.13-1.mga7
+ Revision: 1253498
- security update mga#23186

* Sun May 13 2018 zezinho <zezinho> 0.18.11-1.mga7
+ Revision: 1228733
- new version 0.18.11

* Fri May 04 2018 zezinho <zezinho> 0.18.10-1.mga7
+ Revision: 1226216
- new version 0.18.10

* Mon Apr 30 2018 ovitters <ovitters> 0.18.9-2.mga7
+ Revision: 1224029
- rebuild for missing signature

* Fri Apr 27 2018 zezinho <zezinho> 0.18.9-1.mga7
+ Revision: 1222835
- new version 0.18.9 security fix

* Mon Apr 16 2018 daviddavid <daviddavid> 0.18.8-2.mga7
+ Revision: 1219273
- rebuild for new jasper 2.0.14

* Sun Mar 04 2018 zezinho <zezinho> 0.18.8-1.mga7
+ Revision: 1206455
- new version 0.18.8 security fix MGA#22695

* Wed Dec 20 2017 ns80 <ns80> 0.18.6-1.mga7
+ Revision: 1183526
- new version 0.18.6 that corrects CVE-2017-16910 (mga#22243)

* Fri Sep 29 2017 ns80 <ns80> 0.18.5-1.mga7
+ Revision: 1161578
- new version 0.18.5 for CVE-2017-14348 (mga#21716)

* Fri Sep 22 2017 ns80 <ns80> 0.18.4-1.mga7
+ Revision: 1157163
- new version 0.18.4 that fixes CVE-2017-13735 and CVE-2017-14265 (mga#21716)

* Sun Apr 09 2017 luigiwalser <luigiwalser> 0.18.2-1.mga6
+ Revision: 1096202
- 0.18.2

* Tue Dec 27 2016 luigiwalser <luigiwalser> 0.18.0-1.mga6
+ Revision: 1078382
- 0.18.0
- library major is now 16

* Wed May 25 2016 luigiwalser <luigiwalser> 0.17.2-1.mga6
+ Revision: 1018481
- 0.17.2

* Sat Dec 26 2015 wally <wally> 0.17.1-1.mga6
+ Revision: 915332
- new version 0.17.1
- new libmajor 15
- drop unneeded patches
- switch back to autotools build as cmake build is not officially supported anymore

* Tue Dec 08 2015 luigiwalser <luigiwalser> 0.16.2-2.mga6
+ Revision: 908921
- add patch from fedora to fix CVE-2015-8366 and CVE-2015-8367

* Mon May 18 2015 luigiwalser <luigiwalser> 0.16.2-1.mga5
+ Revision: 822341
- remove patch now that libkdcraw can work with exceptions
- add patch to revert throwing exception in header file (broke libkdcraw build)
- 0.16.2

* Mon May 11 2015 luigiwalser <luigiwalser> 0.16.1-1.mga5
+ Revision: 821875
- 0.16.1 (fixes integer overflow)

* Wed Oct 15 2014 fwang <fwang> 0.16.0-6.mga5
+ Revision: 751264
- fix all paths

* Wed Oct 15 2014 fwang <fwang> 0.16.0-5.mga5
+ Revision: 751128
- fix include path in cmake
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.16.0-4.mga5
+ Revision: 681744
- Mageia 5 Mass Rebuild

* Mon May 12 2014 neoclust <neoclust> 0.16.0-3.mga5
+ Revision: 622206
- Enable Demosaic Pack GPL3 support and Demosaic Pack GPL2 support support

* Mon Feb 17 2014 neoclust <neoclust> 0.16.0-2.mga5
+ Revision: 593840
- Build with cmake

* Wed Feb 05 2014 wally <wally> 0.16.0-1.mga5
+ Revision: 583410
- new version 0.16.0
- new major 10

* Sat Oct 19 2013 umeabot <umeabot> 0.15.4-2.mga4
+ Revision: 533512
- Mageia 4 Mass Rebuild

* Sat Aug 31 2013 luigiwalser <luigiwalser> 0.15.4-1.mga4
+ Revision: 473728
- 0.15.4

* Fri Jul 12 2013 luigiwalser <luigiwalser> 0.15.3-1.mga4
+ Revision: 453470
- 0.15.3

* Tue May 28 2013 wally <wally> 0.15.2-1.mga4
+ Revision: 429634
- new version 0.15.2
- new major 9

* Sat Jan 12 2013 umeabot <umeabot> 0.14.7-5.mga3
+ Revision: 358060
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Graphics/Other -> Graphics/Utilities

* Fri Nov 30 2012 ovitters <ovitters> 0.14.7-4.mga3
+ Revision: 323441
- clean spec
- fix rpm group

* Sun Jul 08 2012 fwang <fwang> 0.14.7-3.mga3
+ Revision: 268850
- br jasper

* Sun Jul 08 2012 fwang <fwang> 0.14.7-2.mga3
+ Revision: 268846
- use lcms2

* Sun Jul 08 2012 wally <wally> 0.14.7-1.mga3
+ Revision: 268841
- new version 0.14.7

* Sun Jun 03 2012 tv <tv> 0.14.6-1.mga3
+ Revision: 253663
- new release

* Tue Dec 27 2011 wally <wally> 0.14.5-1.mga2
+ Revision: 188169
- new version 0.14.5

* Wed Dec 14 2011 wally <wally> 0.14.4-1.mga2
+ Revision: 181533
- new version 0.14.4

* Fri Oct 28 2011 fwang <fwang> 0.14.3-1.mga2
+ Revision: 158927
- new version 0.14.3
+ schultz <schultz>
- update to 0.14.1
- clean .spec

* Sun Oct 09 2011 wally <wally> 0.14.0-1.mga2
+ Revision: 153494
- new version 0.14.0
- new major 5
- new version 0.13.8

* Tue Jul 05 2011 wally <wally> 0.13.6-2.mga2
+ Revision: 118879
- disable static build
- fix lib package summaries

* Mon Jul 04 2011 fwang <fwang> 0.13.6-1.mga2
+ Revision: 118392
- new version 0.13.6

* Tue Jun 14 2011 wally <wally> 0.13.5-1.mga2
+ Revision: 106182
- new version 0.13.5

* Sat May 07 2011 wally <wally> 0.13.2-4.mga1
+ Revision: 95859
- drop empty package
- libify devel package
- tag more files as doc
- prettify .spec a bit

* Thu Mar 24 2011 boklm <boklm> 0.13.2-3.mga1
+ Revision: 76181
- rebuild for bug #497

* Thu Mar 10 2011 mikala <mikala> 0.13.2-2.mga1
+ Revision: 67695
- Disable disable-openmp
- Remove _disable_ld_no_undefined

* Thu Mar 10 2011 mikala <mikala> 0.13.2-1.mga1
+ Revision: 67667
- use make instead of %%make
- Update tarball to 0.13.2
- Add LibRaw-demosaic-pack-GPL2
- Add LibRaw-demosaic-pack-GPL3
- Update License to GPLv3
- Add a -tools subpackage where binary are stored
- Clean spec
- imported package libraw


* Fri Jan 07 2011 Funda Wang <fwang@mandriva.org> 0.12.2-1mdv2011.0
+ Revision: 629452
- new version 0.12.2

* Thu Nov 25 2010 Funda Wang <fwang@mandriva.org> 0.10.0-1mdv2011.0
+ Revision: 600929
- update to new version 0.10.0

* Tue Aug 03 2010 Funda Wang <fwang@mandriva.org> 0.9.1-1mdv2011.0
+ Revision: 565591
- update tag
- import libraw


